<?php

/* 
 * dbquery.inc - the script performing the database query and creating the HTML output for it
 *
 * Copyright (c) by Andreas S. Krebs (andreas.krebs@web.de)
 *
 * this script expects in the variable $query the WHERE clause of the SQL query to perform
 * and returns in $entries_found the number of entries found in the database.
 *
 */

require_once("config.inc");
require_once("utils.inc");

if(!$conn)	// recycle connection if already existing
  $conn=pg_connect("host=$DBHOST user=$DBUSER dbname=$DBNAME");
if(!$conn)
{
  echo("<TR><TD CLASS=Navigation WIDTH=\"100%\" ALIGN=CENTER><B>Failed to open the database $DB_NAME at $DB_HOST for $DB_USER</TD></TR>");
}
else
{
  // Execute query (we also get the oid, also we don't need it yet)
  if($sortby == "")
    $sortby="artist ASC,title ASC,album ASC";

  $sortdir="ASC";
  $isortdir="DESC";
  if(stristr($sortby, "ASC") === false)
  {
    $sortdir="DESC";
    $isortdir="ASC";
  }
  
  $result=pg_exec($conn,"SELECT * FROM songs WHERE $query ORDER BY $sortby;");

  $entries_found=pg_numrows($result);

  if($start >= $entries_found)		// make sure the start range is valid
    $start=0;

  // Create result table header
  echo("<TABLE CELLSPACING=4 CELLPADDING=0 BORDER=$TABLE_BORDER WIDTH=\"100%\">");

  if($entries_found <= 0)
  {
    echo("<TR><TD CLASS=Navigation WIDTH=\"100%\" ALIGN=CENTER><B>$notfound_msg</B></TD></TR>");
  }
  else
  {
    $end=$start + $MAX_ENTRIES;
    if($end > $entries_found)
      $end=$entries_found;

    $colspan=10;
    if($SHOW_COMPOSER)
      $colspan++;

    if($entries_found > 1)
    {
      echo("
<TR><TD CLASS=Navigation ALIGN=CENTER COLSPAN=$colspan><B>Entries ". ($start+1) ." - $end of $entries_found");

      if($entries_found > $MAX_ENTRIES)
      {
        // create the page HTML  
        $pagehtml=getPageHTML($SCRIPT_NAME."?".$QUERY_STRING, $start, $entries_found, $MAX_ENTRIES);

        echo("<BR>$pagehtml");
      }

      echo("</B></TD></TR>");

      $newquery=$QUERY_STRING;
      $newquery=ereg_replace("sortby=.*&", "", $newquery);
      $newquery=ereg_replace("&sortby=.*^", "", $newquery);  // in case we are at the end of the query
      $newquery=$SCRIPT_NAME . "?" . $newquery . "&sortby=";

      $isortby=ereg_replace($sortdir, $isortdir, $sortby);
      $indirquery=$newquery . rawurlencode($isortby);

      $sortimg=ereg_replace("ASC", "images/down.gif", $isortdir);
      $sortimg=ereg_replace("DESC", "images/up.gif", $sortimg);
 
      $sortalt=ereg_replace("ASC", "[Down]", $isortdir);
      $sortalt=ereg_replace("DESC", "[UP]", $isortdir);
      echo("
<TR>
  <TD CLASS=Column WIDTH=1% ALIGN=CENTER><A HREF=\"$indirquery\"><IMG SRC=\"$sortimg\" ALT=\"$sortalt\" BORDER=0></A></TD>
  <TD CLASS=Column WIDTH=1%></TD>
  <TD CLASS=Column ALIGN=CENTER WIDTH=20%><B><A HREF=\"$newquery"."artist+$sortdir%2Ctitle+$sortdir%2Calbum+$sortdir%2Ctrack+$sortdir\">Artist</A></B></TD>");

      if($SHOW_COMPOSER)
        echo("
  <TD CLASS=Column ALIGN=CENTER WIDTH=20%><B><A HREF=\"$newquery"."composer+$sortdir%2Cartist+$sortdir%2Ctitle+$sortdir%2Calbum+$sortdir%2Ctrack+$sortdir\">Composer</A></B></TD>");

      echo("
  <TD CLASS=Column ALIGN=CENTER WIDTH=30%><B><A HREF=\"$newquery"."title+$sortdir%2Cartist+$sortdir%2Calbum+$sortdir%2Ctrack+$sortdir\">Title</A></B></TD>
  <TD CLASS=Column ALIGN=CENTER WIDTH=20%><B><A HREF=\"$newquery"."album+$sortdir%2Ctrack+$sortdir%2Cartist+$sortdir%2Ctitle+$sortdir\">Album [Track]</A></B></TD>
");
    }
    else  // no need for sorting links, cause we have only one entry 
    {
      echo("
<TR>
  <TD CLASS=Column WIDTH=1%></TD>
  <TD CLASS=Column WIDTH=1%></TD>
  <TD CLASS=Column ALIGN=CENTER WIDTH=20%><B>Artist</B></TD>");

      if($SHOW_COMPOSER)
        echo("<TD CLASS=Column ALIGN=CENTER WIDTH=20%><B>Composer</B></TD>");

      echo("
  <TD CLASS=Column ALIGN=CENTER WIDTH=30%><B>Title</B></TD>
  <TD CLASS=Column ALIGN=CENTER WIDTH=20%><B>Album [Track]</B></TD>
");
    }

    echo("
  <TD CLASS=Column ALIGN=CENTER WIDTH=5%><B>Length</B></TD>
  <TD CLASS=Column ALIGN=CENTER WIDTH=5%><B>kbps</B></TD>
  <TD CLASS=Column ALIGN=CENTER WIDTH=5%><B>Size</B></TD>
  <TD CLASS=Column ALIGN=CENTER WIDTH=1%><B>File</B></TD>
  <TD CLASS=Column ALIGN=CENTER WIDTH=1%><B>Edit</B></TD>
</TR>
");

    // Get results from database

    $rows=$start;
    while($rows < $end)
    {
      $song=pg_fetch_object($result, $rows);

      // Encode URLs
      $url=rawurlencode($song->file);
      $url=$LINKROOT . $song->file;

      $song->fileurl=rawurlencode($MP3ROOT . $song->file);
      $uartist=rawurlencode($song->artist);
      $ucomposer=rawurlencode($song->composer);
      $utitle=rawurlencode($song->title);
      $ualbum=rawurlencode($song->album);

      $ftime=formatSeconds($song->length);
      $fsize=formatSize($song->filesize);

      // convert html special chars where needed
      $song->artist=htmlspecialchars($song->artist);
      $song->composer=htmlspecialchars($song->composer);
      $song->title=htmlspecialchars($song->title);
      $song->album=htmlspecialchars($song->album);

      // create a table row for this entry 
      $style="Entry";
      if(strlen($song->album)==0 && $song->track==false)
        $style="NoEntry";

      if($song->track==false)
        $track="";
      else
        $track=" [$song->track]";

      echo("
<TR>
  <TD CLASS=Number $ENTRY_ATTR ALIGN=RIGHT><A HREF=\"info.php?id=$song->id\" TARGET=\"_blank\">". ($rows+1) ."</A>.</TD>
  <TD CLASS=Button $ENTRY_ATTR><A HREF=\"irmp3cmd.php?comand=play&file=$song->fileurl\" TARGET=\"player\"><IMG SRC=\"images/play.gif\" ALT=\"[Play]\" BORDER=0></A></TD>
  <TD CLASS=Entry $ENTRY_ATTR><A HREF=\"search.php?artist=$uartist\">$song->artist</A></TD>");

      if($SHOW_COMPOSER)
      {
        $cstyle="Entry";
        if(strlen($song->composer)==0)
          $cstyle="NoEntry";

        echo("<TD CLASS=$cstyle $ENTRY_ATTR><A HREF=\"search.php?composer=$ucomposer\">$song->composer</A></TD>");
      }

      echo("
  <TD CLASS=Entry $ENTRY_ATTR><A HREF=\"search.php?title=$utitle\">$song->title</A></TD>
  <TD CLASS=$style $ENTRY_ATTR><A HREF=\"search.php?album=$ualbum\">$song->album</A>$track</TD>
  <TD CLASS=Entry $ENTRY_ATTR ALIGN=RIGHT>$ftime</TD>
  <TD CLASS=Entry $ENTRY_ATTR ALIGN=RIGHT>$song->bitrate</TD>
  <TD CLASS=Entry $ENTRY_ATTR ALIGN=RIGHT>$fsize</TD>
  <TD CLASS=Button $ENTRY_ATTR><A HREF=\"$url\"><IMG SRC=\"images/download.gif\" ALT=\"[Download]\" BORDER=0></A></TD>
  <TD CLASS=Button $ENTRY_ATTR><A HREF=\"manage/edit.php?id=$song->id\" TARGET=\"_blank\"><IMG SRC=\"images/edit.gif\" ALT=\"[Edit]\" BORDER=0></A></TD>
</TR>
      ");

      $rows++;
    }

    if($entries_found > $MAX_ENTRIES)
      echo("<TR><TD CLASS=Navigation ALIGN=MIDDLE COLSPAN=$colspan><B>$pagehtml<B></TD></TR>");
  }

  echo("</TABLE>");

  pg_close($conn);
}

function getPageHTML($query, $start, $num, $max)
{
  $query=ereg_replace("start=.*&", "", $query);
  $query=ereg_replace("&start=.*^", "", $query);  // in case we are at the end of the query
  $query=$query . "&start=";

  $html="";
  if($num > $max)
  {
    $prev=$start - $max;
    if($prev < 0)
      $prev=-1;

    $next=$start + $max;
    if($next >= $num)
      $next=-1;

    if($prev >= 0)
      $html.="<A HREF=\"". $query ."0\">&lt;&lt</A> \n<A HREF=\"". $query . $prev ."\">&lt</A> \n";
    else
      $html.="&lt;&lt; &lt; \n";

    $cnt=1;
    for($i=0; $i<$num; $i+=$max)
    {
      if($i != $start)
        $html.="<A HREF=\"". $query . $i ."\">$cnt</A> \n";
      else
        $html.="<FONT COLOR=#99aabb>$cnt</FONT> \n";

      $end=$i;
      $cnt++;
    }

    if($next >= 0)
      $html.="<A HREF=\"". $query . $next ."\">&gt;</A> <A HREF=\"". $query . $end ."\">&gt;&gt;</A>\n";
    else
      $html.="&gt; &gt;&gt;\n";
  }

  return $html;
}

?>

